B-FeelLog
=========

.. figure:: https://github.com/jero98772/B-FeelLog/blob/main/docs/Screenshots/B-feelog_logo1.jpg?raw=true
   :alt: logo

   logo
::

        Blog feel-log ,feel Blog   

free source minimal multilingual blog maker and manager for different
blog entries and multiple blog entries , with web interface. in this
blog can use images but we looking to keep it minimalism.

now is bilingual with support in - Spanish - English - German - Basque -
Italian - Russian

**more information**
`here <https://github.com/jero98772/B-FeelLog/blob/main/docs/FAQs.md>`__

**video tutorial** `here <https://vimeo.com/manage/videos/580068235>`__

please report some issues or if you need help ### Made for: manage a
blog ,sharing and proposing a tool for expressing

Download
~~~~~~~~

Download repo

::

    git clone https://github.com/jero98772/B-FeelLog.git

Update
~~~~~~

run in repo folder

::

    git pull

Install
~~~~~~~

run install :

::

    python setup.py install

Usage
~~~~~

the app run in `localhost:9600 <http://localhost:9600/this.html>`__
remember you need authenticate in `localhost:9600/blog/< TOKEN
>/ <localhost:9600/this/defaulttoken/>`__ the initial token is:

::

    defaulttoken

Screenshots
~~~~~~~~~~~

|main| |flex blog| |translation|

.. |main| image:: https://github.com/jero98772/B-FeelLog/blob/main/docs/Screenshots/2021-05-06-185257_770x321_scrot.png
.. |flex blog| image:: https://github.com/jero98772/B-FeelLog/blob/main/docs/Screenshots/2021-05-06-165512_752x551_scrot.png
.. |translation| image:: https://github.com/jero98772/B-FeelLog/blob/main/docs/Screenshots/2021-05-07-203242_822x595_scrot.png
